==> claromentis-framework-9.6.6-26891208.zip: web/intranet/common/classes/notification/NotificationActionList.php <==
<?php
$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"] ?: array()) + array("_7f628626dd1d55c" . "71b1fc0932ffd1d2" . "c" => base64_decode("aXNfYXJyYXk" . "="), "_0c5123aa7" . "44f69bbc0e" . "8b3ea2f6e8" . "47d" => base64_decode("bG" . "1z" . "Zw" . "=="), "_a0784e8fe4c87f1feae" . "0bebdd0d06396" => base64_decode("QmFkIHBhcmFtZXRlciBmb3Igbm90aWZpY2F0aW9uIGFjdGlvbiByZWdpc3RyYXR" . "pb24="), "_58d506edba9ce8" . "0af6a061b73e2eb" . "66c" => base64_decode("X" . "w" . "=" . "="), "_9a6f706683ec01145bc6ba" . "58e79f70af" => base64_decode("ZG9jdW1lbnRzLm5vdGlmaWNhdGlvbi5vY" . "mplY3RfY29uc3RydWN0aW9uX2ZhaWxlZA" . "=="), "_5e21294dde7" . "b1c408f94ea4" . "562905336" => base64_decode("ZG9jdW1lbnRzLm5vdGlmaWNhd" . "Glvbi53cm9uZ19zZW5kZXJfdH" . "lwZQ=="));





class NotificationActionList extends ErrorHandler
{
    protected $group_list = array();
    protected $ignore_state = false;
    
    
    
    
    
    
    
    protected function GetGroupList()
    {
        return $this->group_list;
    }
    
    
    
    
    
    
    public function GetIgnoreState()
    {
        return $this->ignore_state;
    }
    
    
    
    
    
    
    
    
    public function SetIgnoreState($_3b091809f4ff2106296a711d24404d00)
    {
        $this->ignore_state = $_3b091809f4ff2106296a711d24404d00;
        return true;
    }
    
    
    
    
    
    
    
    public function RegisterActionList($_cb5635b9995b244fc2d146d5df946b5b)
    {
        $_cf132a3965c3793c96f9ea1e0cc03334 = $_cb5635b9995b244fc2d146d5df946b5b->GetGroupList();
        foreach ($_cf132a3965c3793c96f9ea1e0cc03334 as $_2b76ddf3d6cb9d973ac9026aac5b37cf) {
            foreach ($_2b76ddf3d6cb9d973ac9026aac5b37cf as $_89f798b7c64d55e71d11d4d56f944cb4) {
                $this->RegisterActionObject($_89f798b7c64d55e71d11d4d56f944cb4);
            }
        }
        return true;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    public function RegisterAction($_44e986c04f41a08b56a383c7b3a88ee2, $event, $comment = "", $_35533084fbc43d16244ada11e8c13d78 = null)
    {
        if (!$_44e986c04f41a08b56a383c7b3a88ee2 instanceof ClaAggregation) {
            throw new Exception($GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_0c5123aa744f69bbc0e8b3ea2f6e8" . "47d"]($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_5e21294dde7b1c408f94ea456290" . "5336"]));
        }
        $_824461d985bd8409df53752872790d46 = null;
        
        
        switch ($_44e986c04f41a08b56a383c7b3a88ee2->GetAggregation()) {
            case AGGREGATION_DATA:
                $_824461d985bd8409df53752872790d46 = new DocsNotificationDocumentAction();
                break;
            case AGGREGATION_FOLDER:
                $_824461d985bd8409df53752872790d46 = new DocsNotificationFolderAction();
                break;
        }
        
        
        if (!$_824461d985bd8409df53752872790d46 instanceof NotificationAction) {
            throw new Exception($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_0c5123aa744f69bbc0e8b3" . "ea2f6e847d"]($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_9a6f706683ec01145bc6ba58e7" . "9f70af"]));
        }
        $_824461d985bd8409df53752872790d46->SetSender($_44e986c04f41a08b56a383c7b3a88ee2);
        $_824461d985bd8409df53752872790d46->SetEvent($event);
        $_824461d985bd8409df53752872790d46->SetMessageArg($_35533084fbc43d16244ada11e8c13d78);
        $_824461d985bd8409df53752872790d46->SetComment($comment);
        $_6d531f6dc9e331a0e9b18556f51742ea = $this->RegisterActionObject($_824461d985bd8409df53752872790d46);
        
        
        switch ($_44e986c04f41a08b56a383c7b3a88ee2->GetAggregation()) {
            case AGGREGATION_DATA:
                
                
                
                $_9a329caee83eb0d232953fd253bc3d6b = $_44e986c04f41a08b56a383c7b3a88ee2->GetData();
                $_aa403eb0e17d9b3176d57272c946ea1c = $_9a329caee83eb0d232953fd253bc3d6b->GetAllParents();
                $_936cd9361788a87f2124936606742412 = null;
                if ($event == NOTIFICATION_EVENT_CHANGE || $event == NOTIFICATION_EVENT_CONTENT_CHANGE) {
                    $_936cd9361788a87f2124936606742412 = NOTIFICATION_EVENT_CONTENT_CHANGE;
                }
                if ($event == NOTIFICATION_EVENT_DELETE) {
                    $_936cd9361788a87f2124936606742412 = NOTIFICATION_EVENT_CONTENT_DELETE;
                }
                if ($event == NOTIFICATION_EVENT_UNDELETE) {
                    $_936cd9361788a87f2124936606742412 = NOTIFICATION_EVENT_CONTENT_UNDELETE;
                }
                if ($_936cd9361788a87f2124936606742412 && $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_7f628626dd1d55c71b" . "1fc0932ffd1d2c"]($_aa403eb0e17d9b3176d57272c946ea1c)) {
                    foreach ($_aa403eb0e17d9b3176d57272c946ea1c as $_4e7db93b73495d62b6fe61a190365822) {
                        $this->RegisterAction($_4e7db93b73495d62b6fe61a190365822, $_936cd9361788a87f2124936606742412, $comment, $_9a329caee83eb0d232953fd253bc3d6b);
                        
                        
                    }
                }
                break;
            case AGGREGATION_FOLDER:
                
                
                
                $_936cd9361788a87f2124936606742412 = null;
                $_2354db9735250f428fb1076274978c40 = null;
                if ($_35533084fbc43d16244ada11e8c13d78) {
                    
                    
                    $_936cd9361788a87f2124936606742412 = $event;
                    $_2354db9735250f428fb1076274978c40 = $_35533084fbc43d16244ada11e8c13d78;
                } else {
                    if ($event == NOTIFICATION_EVENT_CHANGE) {
                        $_936cd9361788a87f2124936606742412 = NOTIFICATION_EVENT_CONTENT_CHANGE;
                    }
                    if ($event == NOTIFICATION_EVENT_DELETE) {
                        $_936cd9361788a87f2124936606742412 = NOTIFICATION_EVENT_CONTENT_DELETE;
                    }
                    if ($event == NOTIFICATION_EVENT_UNDELETE) {
                        $_936cd9361788a87f2124936606742412 = NOTIFICATION_EVENT_CONTENT_UNDELETE;
                    }
                    $_2354db9735250f428fb1076274978c40 = $_44e986c04f41a08b56a383c7b3a88ee2;
                }
                if (!$_35533084fbc43d16244ada11e8c13d78 && $_44e986c04f41a08b56a383c7b3a88ee2->GetParentId()) {
                    
                    
                    $_4e7db93b73495d62b6fe61a190365822 = $_44e986c04f41a08b56a383c7b3a88ee2->GetParent();
                    if ($_936cd9361788a87f2124936606742412 && $_4e7db93b73495d62b6fe61a190365822 && $_4e7db93b73495d62b6fe61a190365822->GetAggregation() == AGGREGATION_FOLDER) {
                        $this->RegisterAction($_4e7db93b73495d62b6fe61a190365822, $_936cd9361788a87f2124936606742412, $comment, $_2354db9735250f428fb1076274978c40);
                        
                        
                    }
                }
                break;
        }
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
    
    
    
    
    
    
    
    
    public function RegisterActionObject($_89f798b7c64d55e71d11d4d56f944cb4)
    {
        if ($this->ignore_state) {
            return true;
        }
        if (!$_89f798b7c64d55e71d11d4d56f944cb4 instanceof NotificationAction) {
            return $this->SetErrMsg($GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_a0784e8fe4c87" . "f1feae0bebdd0d" . "06396"]);
        }
        $_d9105a4aee78f39e3d35e04a8f7b6d32 = $_89f798b7c64d55e71d11d4d56f944cb4->GetSender()->GetAggregation() . $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_58d506edba9ce80af6a061b73e2eb6" . "6c"] . $_89f798b7c64d55e71d11d4d56f944cb4->GetSender()->GetId();
        if (!isset($this->group_list[$_d9105a4aee78f39e3d35e04a8f7b6d32]) || !$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_7f628626dd1d" . "55c71b1fc0932" . "ffd1d2c"]($this->group_list[$_d9105a4aee78f39e3d35e04a8f7b6d32])) {
            $this->group_list[$_d9105a4aee78f39e3d35e04a8f7b6d32] = array();
        }
        $this->group_list[$_d9105a4aee78f39e3d35e04a8f7b6d32][] = $_89f798b7c64d55e71d11d4d56f944cb4;
        return true;
    }
    
    
    
    
    
    
    
    public function ClearActions()
    {
        $this->group_list = [];
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/common/classes/notification/NotificationActionList.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"] = (@$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"] ?: array()) + array("_a0784e8fe4c87f1feae0beb" . "dd0d06396" => base64_decode("QmFkIHBhcmFtZXRlciBmb3Igbm90aWZpY2F0aW9uIGFjdGlvbiByZWdpc3RyYXRp" . "b24="), "_7f628626dd1d55c71b1fc0932ffd" . "1d2c" => base64_decode("aXNfYXJyY" . "Xk="), "_9a6f706683ec01145bc6ba58e79f" . "70af" => base64_decode("ZG9jdW1lbnRzLm5vdGlma" . "WNhdGlvbi5vYmplY3RfY2" . "9uc3RydWN0aW9uX2ZhaWx" . "lZA=="), "_0c5123aa7" . "44f69bbc0e" . "8b3ea2f6e8" . "47d" => base64_decode("bG1z" . "Zw=="), "_58d506edba9ce80af6a" . "061b73e2eb66c" => base64_decode("Xw=" . "="), "_5e21294dde7b1c408f94ea45" . "62905336" => base64_decode("ZG9jdW1lbnRzLm5vdGlmaWNhdGlvbi53cm9uZ1" . "9zZW5kZXJfdHlwZQ=="));





class NotificationActionList extends ErrorHandler
{
    protected $group_list = array();
    protected $ignore_state = false;
    
    
    
    
    
    
    
    protected function GetGroupList()
    {
        return $this->group_list;
    }
    
    
    
    
    
    
    public function GetIgnoreState()
    {
        return $this->ignore_state;
    }
    
    
    
    
    
    
    
    
    public function SetIgnoreState($_3b091809f4ff2106296a711d24404d00)
    {
        $this->ignore_state = $_3b091809f4ff2106296a711d24404d00;
        return true;
    }
    
    
    
    
    
    
    
    public function RegisterActionList($_cb5635b9995b244fc2d146d5df946b5b)
    {
        $_cf132a3965c3793c96f9ea1e0cc03334 = $_cb5635b9995b244fc2d146d5df946b5b->GetGroupList();
        foreach ($_cf132a3965c3793c96f9ea1e0cc03334 as $_2b76ddf3d6cb9d973ac9026aac5b37cf) {
            foreach ($_2b76ddf3d6cb9d973ac9026aac5b37cf as $_89f798b7c64d55e71d11d4d56f944cb4) {
                $this->RegisterActionObject($_89f798b7c64d55e71d11d4d56f944cb4);
            }
        }
        return true;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    public function RegisterAction($_44e986c04f41a08b56a383c7b3a88ee2, $event, $comment = "", $_35533084fbc43d16244ada11e8c13d78 = null)
    {
        if (!$_44e986c04f41a08b56a383c7b3a88ee2 instanceof ClaAggregation) {
            throw new Exception($GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_0c5123aa744f69b" . "bc0e8b3ea2f6e847" . "d"]($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_5e21294dde7b1c40" . "8f94ea4562905336"]));
        }
        $_824461d985bd8409df53752872790d46 = null;
        
        
        switch ($_44e986c04f41a08b56a383c7b3a88ee2->GetAggregation()) {
            case AGGREGATION_DATA:
                $_824461d985bd8409df53752872790d46 = new DocsNotificationDocumentAction();
                break;
            case AGGREGATION_FOLDER:
                $_824461d985bd8409df53752872790d46 = new DocsNotificationFolderAction();
                break;
        }
        
        
        if (!$_824461d985bd8409df53752872790d46 instanceof NotificationAction) {
            throw new Exception($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_0c5123aa7" . "44f69bbc0e" . "8b3ea2f6e8" . "47d"]($GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_9a6f706683ec011" . "45bc6ba58e79f70a" . "f"]));
        }
        $_824461d985bd8409df53752872790d46->SetSender($_44e986c04f41a08b56a383c7b3a88ee2);
        $_824461d985bd8409df53752872790d46->SetEvent($event);
        $_824461d985bd8409df53752872790d46->SetMessageArg($_35533084fbc43d16244ada11e8c13d78);
        $_824461d985bd8409df53752872790d46->SetComment($comment);
        $_6d531f6dc9e331a0e9b18556f51742ea = $this->RegisterActionObject($_824461d985bd8409df53752872790d46);
        
        
        switch ($_44e986c04f41a08b56a383c7b3a88ee2->GetAggregation()) {
            case AGGREGATION_DATA:
                
                
                
                $_9a329caee83eb0d232953fd253bc3d6b = $_44e986c04f41a08b56a383c7b3a88ee2->GetData();
                $_aa403eb0e17d9b3176d57272c946ea1c = $_9a329caee83eb0d232953fd253bc3d6b->GetAllParents();
                $_936cd9361788a87f2124936606742412 = null;
                if ($event == NOTIFICATION_EVENT_CHANGE || $event == NOTIFICATION_EVENT_CONTENT_CHANGE) {
                    $_936cd9361788a87f2124936606742412 = NOTIFICATION_EVENT_CONTENT_CHANGE;
                }
                if ($event == NOTIFICATION_EVENT_DELETE) {
                    $_936cd9361788a87f2124936606742412 = NOTIFICATION_EVENT_CONTENT_DELETE;
                }
                if ($event == NOTIFICATION_EVENT_UNDELETE) {
                    $_936cd9361788a87f2124936606742412 = NOTIFICATION_EVENT_CONTENT_UNDELETE;
                }
                if ($_936cd9361788a87f2124936606742412 && $GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_7f628626dd1d55c71b1fc0932ffd" . "1d2c"]($_aa403eb0e17d9b3176d57272c946ea1c)) {
                    foreach ($_aa403eb0e17d9b3176d57272c946ea1c as $_4e7db93b73495d62b6fe61a190365822) {
                        $this->RegisterAction($_4e7db93b73495d62b6fe61a190365822, $_936cd9361788a87f2124936606742412, $comment, $_9a329caee83eb0d232953fd253bc3d6b);
                        
                        
                    }
                }
                break;
            case AGGREGATION_FOLDER:
                
                
                
                $_936cd9361788a87f2124936606742412 = null;
                $_2354db9735250f428fb1076274978c40 = null;
                if ($_35533084fbc43d16244ada11e8c13d78) {
                    
                    
                    $_936cd9361788a87f2124936606742412 = $event;
                    $_2354db9735250f428fb1076274978c40 = $_35533084fbc43d16244ada11e8c13d78;
                } else {
                    if ($event == NOTIFICATION_EVENT_CHANGE) {
                        $_936cd9361788a87f2124936606742412 = NOTIFICATION_EVENT_CONTENT_CHANGE;
                    }
                    if ($event == NOTIFICATION_EVENT_DELETE) {
                        $_936cd9361788a87f2124936606742412 = NOTIFICATION_EVENT_CONTENT_DELETE;
                    }
                    if ($event == NOTIFICATION_EVENT_UNDELETE) {
                        $_936cd9361788a87f2124936606742412 = NOTIFICATION_EVENT_CONTENT_UNDELETE;
                    }
                    $_2354db9735250f428fb1076274978c40 = $_44e986c04f41a08b56a383c7b3a88ee2;
                }
                if (!$_35533084fbc43d16244ada11e8c13d78 && $_44e986c04f41a08b56a383c7b3a88ee2->GetParentId()) {
                    
                    
                    $_4e7db93b73495d62b6fe61a190365822 = $_44e986c04f41a08b56a383c7b3a88ee2->GetParent();
                    if ($_936cd9361788a87f2124936606742412 && $_4e7db93b73495d62b6fe61a190365822 && $_4e7db93b73495d62b6fe61a190365822->GetAggregation() == AGGREGATION_FOLDER) {
                        $this->RegisterAction($_4e7db93b73495d62b6fe61a190365822, $_936cd9361788a87f2124936606742412, $comment, $_2354db9735250f428fb1076274978c40);
                        
                        
                    }
                }
                break;
        }
        return $_6d531f6dc9e331a0e9b18556f51742ea;
    }
    
    
    
    
    
    
    
    
    public function RegisterActionObject($_89f798b7c64d55e71d11d4d56f944cb4)
    {
        if ($this->ignore_state) {
            return true;
        }
        if (!$_89f798b7c64d55e71d11d4d56f944cb4 instanceof NotificationAction) {
            return $this->SetErrMsg($GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_a0784e8fe4c8" . "7f1feae0bebdd" . "0d06396"]);
        }
        $_d9105a4aee78f39e3d35e04a8f7b6d32 = $_89f798b7c64d55e71d11d4d56f944cb4->GetSender()->GetAggregation() . $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_58d506edba9ce80af6a" . "061b73e2eb66c"] . $_89f798b7c64d55e71d11d4d56f944cb4->GetSender()->GetId();
        if (!isset($this->group_list[$_d9105a4aee78f39e3d35e04a8f7b6d32]) || !$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_7f628626dd1d55c71b1fc0932" . "ffd1d2c"]($this->group_list[$_d9105a4aee78f39e3d35e04a8f7b6d32])) {
            $this->group_list[$_d9105a4aee78f39e3d35e04a8f7b6d32] = array();
        }
        $this->group_list[$_d9105a4aee78f39e3d35e04a8f7b6d32][] = $_89f798b7c64d55e71d11d4d56f944cb4;
        return true;
    }
    
    
    
    
    
    
    
    public function ClearActions()
    {
        $this->group_list = [];
    }
}
